@@ -250,7 +250,7 @@ void CouplingPhysicalModel::updateCode()
   code << "            timeout = step.getTimeOut()\n";
   code << "            if timeout <= 0:\n";
   code << "                timeout = None\n";
-  code << "            otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), get_stderr=True, get_stdout=True, timeout=timeout)\n";
+  code << "            otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout)\n";
   code << "        for output_file in step.getOutputFiles():\n";
   code << "            if not output_file.getPath():\n";
   code << "                continue\n";
