@@ -8,11 +8,11 @@
 
 """
 
-import sys
-if sys.platform.startswith('win'):
-    # this ensures OT dll is loaded
-    import openturns
+# flake8: noqa
+
+# ensures swig type tables order & dll load
+import openturns as _ot
 
 from .persalys import *
 
-__version__ = '12.0.1'
+__version__ = '13.1.1'
